<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<xsl:output method="xml" indent="yes" encoding="ISO-8859-1"/>
	<!-- Parmetros pasados al XSL -->
	<!-- currentDate: Fecha actual con formato CCYYMMDDHHMM -->
	<xsl:param name="currentDate" select="'200001011200'"/>
	<!-- sender: Cdigo PAIS+NIF del emisor -->
	<xsl:param name="sender" select="'ESA61961488'"/>
	<!-- receiver: Cdigo PAIS+NIF del receptor -->
	<xsl:param name="receiver" select="'ESA43446522'"/>
	<!-- documentNumber: Nmero de documento -->
	<xsl:param name="documentNumber" select="'A4344652222'"/>
	<!-- messageNumber: Nmero de mensaje -->
	<xsl:param name="messageNumber" select="'2'"/>
	<!-- function: Funcin del mensaje -->
	<xsl:param name="function" select="'5'"/>
	<!-- idtransporte: Identificacin del transporte (matrcula del chofer) -->
	<xsl:param name="idtransporte" select="'B7710IC'"/>
	<!-- nombretransporte: Nombre del chofer -->
	<xsl:param name="nombretransporte" select="'ANTONIO EL CHOFER'"/>
	<!-- fecharecogida: Fecha de recogida de la mercanca en terminal con formato CCYYMMDDHHMM -->
	<xsl:param name="fecharecogida" select="'197601260100'"/>
	<!-- Esta es la matrcula que se coger de la rden de transporte para generar el preaviso -->
	<xsl:param name="matricula" select="'REF8'"/>
	<!-- El e-mail del emisor del documento para que se le pueda notificar va e-mail -->
	<xsl:param name="emailEmisor" select="'jcambra@portic.net'"/>
	<xsl:template match="/">
		<COPINOE05>
		<xsl:call-template name="E05_CABECERA"/>
		<!-- <xsl:call-template name="E05_PARTIDAS"/> -->
		<xsl:call-template name="E05_EQUIPAMIENTOS"/>
		</COPINOE05>
	</xsl:template>

	<!-- CABECERA -->
	<xsl:template name="E05_CABECERA">
			<COPINOE05.HEADER>
				<anxs_interchange.header>
					<anxe_sender.identification>
						<xsl:value-of select="$sender"/>
					</anxe_sender.identification>
					<anxe_recipient.identification>
						<xsl:value-of select="$receiver"/>
					</anxe_recipient.identification>
				</anxs_interchange.header>
				<anxs_message.header>
					<anxe_message.reference.number>
						<xsl:value-of select="$messageNumber"/>
					</anxe_message.reference.number>
					<anxe_message.type>COPINO</anxe_message.type>
					<anxe_message.version.number>D99A</anxe_message.version.number>
				</anxs_message.header>
				<trsd_beginning.of.message>
					<tred_document.message.name.coded>172</tred_document.message.name.coded>
					<tred_document.message.number>
						<xsl:value-of select="$messageNumber"/>
					</tred_document.message.number>
					<tred_message.function.coded>
						<xsl:value-of select="$function"/>
					</tred_message.function.coded>
				</trsd_beginning.of.message>
				<trcd_date.time.period>
					<tred_date.time.period.qualifier>137</tred_date.time.period.qualifier>
					<tred_date.time.period>
						<xsl:value-of select="$currentDate"/>
					</tred_date.time.period>
				</trcd_date.time.period>
				<trsd_free.text>
					<tred_text.subject.qualifier>ZSE</tred_text.subject.qualifier>
					<trcd_text.literal>
						<tred_free.text>
							<xsl:value-of select="$emailEmisor"/>
						</tred_free.text>
					</trcd_text.literal>
				</trsd_free.text>
				<!-- Free Text con tipo ACB (Informaci??n adicional) -->
				<xsl:apply-templates select="descendant::trsd_free.text[tred_text.subject.qualifier='ACB'][1]"/>
				<!-- Free Text con tipo CHG (Informacion de los cambios) -->
				<xsl:apply-templates select="descendant::trsd_free.text[tred_text.subject.qualifier='CHG'][1]"/>
				<!-- Free Text con tipo CHG (Informacion de los cambios) -->
				<xsl:apply-templates select="descendant::trsd_free.text[tred_text.subject.qualifier='DIN'][1]"/>

			</COPINOE05.HEADER>
				<!-- Referencia con tipo BN (Numero de Booking) -->
				<xsl:apply-templates select="descendant::trcd_reference[tred_reference.qualifier='BN'][1]"/> 
				<!-- Referencia con tipo AEL (Numero de Preaviso) -->
				<COPINOE05.GROUP1>
				 	<trcd_reference>
						<tred_reference.qualifier>AEL</tred_reference.qualifier>
                                                <tred_reference.number><xsl:value-of select="$documentNumber"/></tred_reference.number>
					</trcd_reference>
				</COPINOE05.GROUP1>
                                <!--Referencia con tipo ACA (Numero de orden de adm?-tase) --> 
                                <xsl:apply-templates select="descendant::trcd_reference[tred_reference.qualifier='ACA'][1]"/>   
				<!-- Referencia con tipo SI (Referencia del exportador) -->
				<xsl:apply-templates select="descendant::trcd_reference[tred_reference.qualifier='SI'][1]"/> 
				<!-- Referencia con tipo VON (N??mero de escala seg??n APB) -->
				<xsl:apply-templates select="descendant::trcd_reference[tred_reference.qualifier='VON' or tred_reference.qualifier='ESC'][1]"/> 
			<COPINOE05.GROUP2>
				<trsd_details.of.transport>
					<tred_transport.stage.qualifier>10</tred_transport.stage.qualifier>
					<tred_mode.of.transport.coded>3</tred_mode.of.transport.coded>
					<trcd_transport.identification>
						<tred_id.of.the.means.of.transport>
							<xsl:value-of select="$idtransporte"/>
						</tred_id.of.the.means.of.transport>
						<tred_id.of.means.of.transport.identification>
							<xsl:value-of select="$nombretransporte"/>
						</tred_id.of.means.of.transport.identification>
					</trcd_transport.identification>
				</trsd_details.of.transport>
				<trcd_date.time.period>
					<tred_date.time.period.qualifier>76</tred_date.time.period.qualifier>
					<tred_date.time.period>
						<xsl:value-of select="$fecharecogida"/>
					</tred_date.time.period>
				</trcd_date.time.period>
			</COPINOE05.GROUP2>
				<!-- Se selecciona la informacion de nombre y direccion con tipo CN (Consignatario) -->
				<xsl:apply-templates select="descendant::*[trsd_name.and.address/tred_party.qualifier='CN'][1]"/> 
				<!-- Se selecciona la informacion de nombre y direccion con tipo GT (Ferrocarril) o GA (Carretera) (Transporte terrestre) -->
					<COPINOE05.GROUP3>
						<xsl:apply-templates select="descendant::*[trsd_name.and.address/tred_party.qualifier='GT' or trsd_name.and.address/tred_party.qualifier='GA'][1]"/> 
						<xsl:apply-templates select="descendant::*[trsd_contact.information/tred_contact.function.coded='CA'][../trsd_name.and.address/tred_party.qualifier='GT' or ../trsd_name.and.address/tred_party.qualifier='GA'][1]"/> 
						
					</COPINOE05.GROUP3>
				<!-- Se selecciona la informacion de nombre y direccion con tipo TR (Terminal de carga) -->
				<xsl:apply-templates select="descendant::*[trsd_name.and.address/tred_party.qualifier='TR'][1]"/> 
	</xsl:template>
	<xsl:template match="trsd_free.text">
		<xsl:copy-of select="."/>
	</xsl:template>

	<xsl:template match="trcd_reference[tred_reference.qualifier !='ESC']">
		<COPINOE05.GROUP1>
			<xsl:copy-of select="."/>
		</COPINOE05.GROUP1>
	</xsl:template>

           <xsl:template match="trcd_reference[tred_reference.qualifier='ESC']">
		<COPINOE05.GROUP1>
			
			<trcd_reference>
                             <tred_reference.qualifier>VON</tred_reference.qualifier>
                             <tred_reference.number>
                             <xsl:value-of select = "tred_reference.number"/> </tred_reference.number></trcd_reference>
                               
		</COPINOE05.GROUP1>
		
	</xsl:template> 

     

	<xsl:template match="trcd_date.time.period">
		<xsl:copy-of select="."/>
	</xsl:template>

	<xsl:template match="trsd_details.of.transport">
		<xsl:copy-of select="."/>
	</xsl:template>

		
	<xsl:template match="*[trsd_name.and.address/tred_party.qualifier='GT' or trsd_name.and.address/tred_party.qualifier='GA']">
		<xsl:copy-of select="trsd_name.and.address"/>
	</xsl:template>

	<xsl:template match="*[trsd_name.and.address/tred_party.qualifier!='GT' and trsd_name.and.address/tred_party.qualifier!='GA']">
		<COPINOE05.GROUP3>
			<xsl:copy-of select="trsd_name.and.address"/>
		</COPINOE05.GROUP3>
	</xsl:template>
	
	<xsl:template match="trsd_contact.information[tred_contact.function.coded='CA'][1]">
		<xsl:copy-of select="."/>
	</xsl:template>

	<xsl:template match="trcd_communication.contact[1]">
		<xsl:copy-of select="."/>
	</xsl:template>
	
	<xsl:template match="*[trsd_contact.information/tred_contact.function.coded='CA'][../trsd_name.and.address/tred_party.qualifier='GT' or ../trsd_name.and.address/tred_party.qualifier='GA'][1]">
		<COPINOE05.GROUP4>
			<xsl:apply-templates  select="descendant::trsd_contact.information[tred_contact.function.coded='CA'][1]"/>
			<xsl:apply-templates  select="descendant::trcd_communication.contact[1]"/>
		</COPINOE05.GROUP4>
	</xsl:template> 

	<!-- PARTIDAS -->
	<xsl:template name="E05_PARTIDAS">
			<COPINOE05.GROUP5>
				<xsl:call-template name="Partida">
					<xsl:with-param name="arbol" select="*[descendant::trsd_goods.item.details][1]"/>
				</xsl:call-template>
			</COPINOE05.GROUP5>
	</xsl:template>

	<xsl:template name="Partida">
                <xsl:param name="arbol"/> 
		<!-- Se selecciona el goods items details (deberian ser iguales en todas las copias pero cogemos el primero) -->
		<xsl:apply-templates select="$arbol/descendant::trsd_goods.item.details[1]"/>
		<!-- Se seleccionan los segmentos SGP  -->
		<xsl:apply-templates select="$arbol/descendant::trsd_split.goods.placement"/>			
		<!-- Se seleccionan los segmentos DGS y FTX de las MMPP  -->
		<xsl:apply-templates select="/root/descendant-or-self::*[trsd_dangerous.goods][1]"/>			
	</xsl:template>
	
	<xsl:template match="trsd_split.goods.placement">
			<xsl:if test="tred_equipment.identification.number">
				<xsl:copy-of select="."/>
			</xsl:if>
			<xsl:if test="trcd_equipment.identification">
				<trsd_split.goods.placement>
					<tred_equipment.identification.number>
						<xsl:value-of select="trcd_equipment.identification"/>
					</tred_equipment.identification.number>
					<tred_number.of.packages>
						<xsl:value-of select="tred_number.of.packages"/>
					</tred_number.of.packages>
				</trsd_split.goods.placement>
			</xsl:if>
	</xsl:template>

	<xsl:template match="trsd_goods.item.details">
			<xsl:copy-of select="."/>
	</xsl:template>
	
	<xsl:template match="*[trsd_dangerous.goods]">
		<COPINOE05.GROUP6>
			<xsl:if test="trsd_free.text/trcd_text.literal">
				<xsl:copy-of select="trsd_dangerous.goods"/>
				<xsl:copy-of select="descendant::trsd_free.text[tred_text.subject.qualifier='AAD'][1]"/>
				<xsl:copy-of select="descendant::trsd_free.text[tred_text.subject.qualifier='AAC'][1]"/>	
			</xsl:if>
			<xsl:if test="trsd_free.text/tred_free.text1">
				<xsl:copy-of select="trsd_dangerous.goods"/>
				<xsl:for-each select="trsd_free.text">
					<trsd_free.text>
						<tred_text.subject.qualifier>
							<xsl:value-of select="tred_text.subject.qualifier"/>
						</tred_text.subject.qualifier>
						<trcd_text.literal>
								<tred_free.text>
									<xsl:value-of select="tred_free.text1"/>
							</tred_free.text>
						</trcd_text.literal>
					</trsd_free.text>
				</xsl:for-each>
			</xsl:if>
		</COPINOE05.GROUP6>
	</xsl:template>

	<xsl:template match="trsd_free.text[tred_text.subject.qualifier]">
		<xsl:copy-of select="."/>
	</xsl:template>

	<!-- EQUIPAMIENTOS -->
	<xsl:template name="E05_EQUIPAMIENTOS">
		<xsl:for-each select="/IFTMINE03/IFTMINE03.GROUP37">
			<xsl:variable name="estamatricula" select="descendant::tred_reference.number"/>
			<xsl:if test="descendant::tred_reference.number and $matricula=$estamatricula">
				<xsl:variable name="numero" select="descendant::tred_equipment.identification.number[1]"/>
				<COPINOE05.GROUP8>
					<!-- Se selecciona el segmento equipments details (debieran ser iguales en todas las copias pero cogemos el primero) -->
					<xsl:apply-templates select="descendant::trsd_equipment.details[1]"/>
					<!-- Referencia con tipo SQ (Numero scuelcial del contenedor)Si no se encuentra, se pone la matricula -->
					<xsl:choose>
						<xsl:when test="/root/descendant::trcd_reference[tred_reference.qualifier='SQ'][1]">
							 <xsl:apply-templates select="/root/descendant::trcd_reference[tred_reference.qualifier='SQ'][1]"/> 
						</xsl:when>
						<xsl:otherwise>
							<trcd_reference>
								<tred_reference.qualifier>SQ</tred_reference.qualifier>
								<tred_reference.number>
									 <xsl:value-of select="descendant::trcd_reference[1]/tred_reference.number"/> 
								</tred_reference.number>
							</trcd_reference>
						</xsl:otherwise>
					</xsl:choose>
					<!-- Se selecciona el segmento MEA (con codigo AET, peso bruto o AAD, en caso de que provenga del IFTMCS) -->
					<!-- <xsl:apply-templates select="descendant::trsd_measurements[tred_measurement.dimension.coded = 'AET'][1]"/> -->
					<!-- <xsl:apply-templates select="descendant::IFTMCS.GROUP35/trsd_measurements[tred_measurement.dimension.coded = 'AAD'][1]"/> -->
					 <xsl:apply-templates select="descendant::trsd_measurements[tred_measurement.dimension.coded = 'AET' or ancestor::IFTMCS.GROUP35/trsd_measurements/tred_measurement.dimension.coded = 'AAD'][1]"/>
					
					<!-- Se selecciona el segmento DIM -->
					<xsl:apply-templates select="descendant::trcd_dimensions[1]"/>
					<!-- Se selecciona el texto libre de tipo AAA (Descripcion de la mercancia) (Hay que cogerlo de la partida!!!!!) -->
					<!-- <xsl:apply-templates select="/root/*[descendant::trsd_split.goods.placement/tred_equipment.identification.number=$numero and descendant::trsd_free.text/tred_text.subject.qualifier = 'AAA'][1]/descendant::trsd_free.text[tred_text.subject.qualifier = 'AAA'][1]"/> -->
					<!-- <xsl:apply-templates select="descendant::trsd_free.text[tred_text.subject.qualifier = 'AAA'][1]"/> 
					<xsl:apply-templates select="/root/*[descendant::trsd_split.goods.placement/trcd_equipment.identification=$numero or descendant::trsd_split.goods.placement/tred_equipment.identification.number=$numero and descendant::trsd_free.text/tred_text.subject.qualifier = 'AAA'][1]/descendant::trsd_free.text[tred_text.subject.qualifier = 'AAA'][1]"/> -->
					
					<!-- Se selecciona el segmento FTX (con codigo AEB, temperatura de transporte, en el resto de los mensajes es un segmento TMP o RNG, puede aparecer tanto en los equipamientos como en la partida) -->
					<xsl:apply-templates select="/root/*[descendant::tred_equipment.identification.number=$numero][descendant::tred_text.subject.qualifier = 'AEB' or descendant::tred_temperature.setting or descendant::tred_range.minimum][1]/descendant::*[tred_text.subject.qualifier = 'AEB' or tred_temperature.setting or tred_range.minimum][1]"/>
					<!-- Se selecciona el segmento FTX (con codigo BLR, observaciones a la documentacion de transporte)(Hay que cogerlo de la partida correspondiente) -->
					<!-- <xsl:apply-templates select="/root/*[descendant::trsd_free.text/tred_text.subject.qualifier = 'BLR'][1]"/> -->
					<!-- <xsl:apply-templates select="/root/COPARNE02/*[descendant::tred_text.subject.qualifier = 'BLR'][1]"/> -->
					<xsl:apply-templates select="descendant::trsd_free.text[ancestor::COPARNE02.GROUP9/trsd_free.text/tred_text.subject.qualifier = 'BLR' or ancestor::IFTMINE03.GROUP37/trsd_free.text/tred_text.subject.qualifier = 'BLR'][1]"/>
					
					<!-- Se selecciona el segmento SEL -->
					<xsl:apply-templates select="descendant::trsd_seal.number[1]"/>
				</COPINOE05.GROUP8>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
	<!-- Difiere del segmento emplado en el IFTMINE03 y el COPARNE02 -->
	<xsl:template match="trsd_equipment.details">
		<trsd_equipment.details>
			<tred_equipment.qualifier> <xsl:value-of select="tred_equipment.qualifier"/> </tred_equipment.qualifier>
			<xsl:if test="tred_equipment.identification.number">
				<tred_equipment.identification.number> <xsl:value-of select="tred_equipment.identification.number"/> </tred_equipment.identification.number>
			</xsl:if>
                        <xsl:if test="tred_equipment.size.and.type.identification">
				<tred_equipment.size.and.type.identification> <xsl:value-of select="tred_equipment.size.and.type.identification"/> </tred_equipment.size.and.type.identification>
			</xsl:if>
		</trsd_equipment.details>		
	</xsl:template>

	<xsl:template match="trcd_reference">
		<xsl:copy-of select="."/>
	</xsl:template>

	<!-- <xsl:template match="trsd_measurements">
			<xsl:copy-of select="."/>
	</xsl:template> -->
	
	<xsl:template match="trsd_measurements">
		<trsd_measurements>
				<tred_measurement.dimension.coded>AET</tred_measurement.dimension.coded>
				<tred_measurement.value>
					<xsl:value-of select="tred_measurement.value"/>
				</tred_measurement.value>
		</trsd_measurements>
	</xsl:template>
	
	
	<xsl:template match="trcd_dimensions">
		<xsl:copy-of select="."/>
	</xsl:template>

	<xsl:template match="trsd_seal.number">
		<xsl:copy-of select="."/>
	</xsl:template>

	<!-- <xsl:template match="trsd_free.text[tred_text.subject.qualifier != 'AEB']">
		<xsl:copy-of select="."/>
	</xsl:template> -->

        <xsl:template match="trsd_free.text">
		<xsl:if test="trcd_text.literal">
			<xsl:copy-of select="."/>
		</xsl:if>
		<xsl:if test="tred_free.text1">
			<trsd_free.text>
				<tred_text.subject.qualifier>
					<xsl:value-of select="tred_text.subject.qualifier"/>
				</tred_text.subject.qualifier>
				<trcd_text.literal>
						<tred_free.text>
							<xsl:value-of select="tred_free.text1"/>
					</tred_free.text>
				</trcd_text.literal>
			</trsd_free.text>
		</xsl:if>
	</xsl:template>
	
	
	<xsl:template match="*[tred_text.subject.qualifier='AEB' or tred_temperature.setting or tred_range.minimum]">
		<xsl:if test="trcd_text.literal">
			<xsl:copy-of select="."/>
		</xsl:if>
		<xsl:if test="tred_range.minimum" >
			<trsd_free.text>
				<tred_text.subject.qualifier>AEB</tred_text.subject.qualifier>
				<trcd_text.literal>
					<tred_free.text>Temperatura de transporte de <xsl:value-of select="tred_range.minimum"/>
					<xsl:text> a </xsl:text>
					<xsl:value-of select="tred_range.maximum"/>
					<xsl:text> grados </xsl:text>
					<xsl:value-of select="tred_measure.unit.qualifier"/> </tred_free.text>
				</trcd_text.literal>
			</trsd_free.text>
		</xsl:if>
		<xsl:if test="tred_temperature.setting">
			<trsd_free.text>
				<tred_text.subject.qualifier>AEB</tred_text.subject.qualifier>
				<trcd_text.literal>
					<tred_free.text> <xsl:value-of select="tred_temperature.setting"/> <xsl:text> </xsl:text> <xsl:value-of select="tred_measure.unit.qualifier"/> </tred_free.text>
				</trcd_text.literal>
			</trsd_free.text>
		</xsl:if>
	</xsl:template>
	
</xsl:stylesheet>
